[![Documentation Status](https://readthedocs.org/projects/poplar/badge/?version=latest)](https://poplar.readthedocs.io/en/latest/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
# poplar
Augmenting selection bias modelling with machine learning for big speedups.

The methodology behind this package is introduced in [arXiv:2212.06166](https://arxiv.org/abs/2212.06166) for the specific case of modelling selection biases in extreme mass ratio inspiral (EMRI) populations. If you use this package in your work, please cite this paper.
